#loading dataset
setwd("/Downloads")
response <- readxl::read_excel('groep18.xlsx', col_names = T)
#loading required packages
library(ggplot2)
library(ggpubr)
library(car)
library(emmeans)

#checking data structure
str(response)
summary(response)

#converting targetemreg and gender to factors
response$targetemreg <- factor(response$targetemreg, c(1, 2, 3), labels = c("Control", "Suppression", "Expression"))
response$gender <- as.factor(response$gender)

#plotting the data/data visualisation
#graph 1
ggline(response, x = "targetemreg", y = "appropriate", color = "gender",
       add = c("mean_se", "jitter"),
       xlab = "Emotion regulation group", ylab = "Appropriateness score",
       legend.title = "Gender", palette = c("#56B4E9", "#CC79A7"))
#graph 2
ggplot(response, aes (x = targetemreg, y = appropriate, color = gender)) + geom_boxplot(outlier.colour = "black", outlier.shape = 8) +
       labs(x = "Emotion regulation group", y = "Appropriateness score", color = "Gender") +
       scale_color_manual(values = c("#56B4E9", "#CC79A7")) + theme_classic()

#conducting 2-way ANOVA
response_model <- aov(appropriate ~ targetemreg * gender, data = response)
summary(response_model)

#checking for ANOVA assumptions
#1. normal distribution
qqnorm(response_model$residuals)
qqline(response_model$residuals)
x <- seq(-5, 5, len = 100)
lines(x, x, col = "red") 
shapiro.test(response_model$residuals)
#2. homogeneity of variance
plot(response_model, 1)
leveneTest(appropriate ~ targetemreg*gender, data=response)

#effect sizes:
SSE_targetemreg <- summary(response_model)[[1]][1,"Sum Sq"]
SSE_gender <- summary(response_model)[[1]][2,"Sum Sq"]
SSE_interaction <- summary(response_model)[[1]][3,"Sum Sq"]
SSE_full <- summary(response_model)[[1]][4,"Sum Sq"]
MSE_full <- summary(response_model)[[1]][4,"Mean Sq"]
DF_targetemreg <- summary(response_model)[[1]][1,"Df"]
DF_gender <- summary(response_model)[[1]][2,"Df"]
#omega^2
omega2_targetemreg <- (SSE_targetemreg-DF_targetemreg*MSE_full)/(SSE_targetemreg+(90-DF_targetemreg)*MSE_full)
omega2_gender <- (SSE_gender-DF_gender*MSE_full)/(SSE_gender+(90-DF_gender)*MSE_full)
omega2_interaction <- (SSE_interaction-(DF_targetemreg*DF_gender)*MSE_full)/(SSE_interaction+(90-(DF_targetemreg*DF_gender))*MSE_full)

#planned contrasts
contrast_model <- lsmeans(response_model, ~ targetemreg)
constrast_pairs <- pairs(contrast_model)
summary(constrast_pairs, adjust = "none", level = .95, infer = c(T,T))

#means and standard deviation for targetemreg:
by(data = response$appropriate, INDICES = response$targetemreg, FUN = mean)
by(data = response$appropriate, INDICES = response$targetemreg, FUN = sd)

#anova and contrasts without outliers
#identify outliers and create new dataset
outliers <- which(response$appropriate > quantile(response$appropriate)[4] + 1.5*IQR(response$appropriate) | 
                  response$appropriate < quantile(response$appropriate)[2] - 1.5*IQR(response$appropriate))
response_outliers <- response[-outliers,]
frequnecy_gender <- table(list(response_outliers$gender))
frequency_target <- table(list(response_outliers$targetemreg)) #unbalanced groups

#unbalanced anova
unbal_response <- lm(appropriate ~ targetemreg*gender,data = response_outliers,
                     contrasts = list(targetemreg = contr.sum, gender = contr.sum))
unbal_mod <- Anova(unbal_response, type=3)
unbal_mod
#classic anova
outlier_model <- aov(appropriate ~ targetemreg * gender, data = response_outliers)
summary(outlier_model)

#contrasts without outliers
contrast_outlier <- lsmeans(outlier_model, ~ targetemreg)
outlier_pairs <- pairs(contrast_outlier)
summary(outlier_pairs, adjust = "none", level = .95, infer = c(T,T))
